@@ -211,7 +211,7 @@ class Vectorizer(vectorization.Vectorization):
                 if not __filter__(token):
                     continue
 
-                key = " + ".join([token[g] for g in self.group_by_field])
+                key = " + ".join([token[g] for g in self.group_by_field]).replace('.', '\u002E')
 
                 # replace . (ngrams like "commissione_._signore")
                 token_field = token[self.token_field].replace('.', '\u002E')
