@@ -1,3 +1,3 @@
 __all__ = ['lexicon', 'impl']
 from compling.analysis.sentiment.impl import SentimentAnalyzer
-from compling.analysis.sentiment.lexicon import Vader, Sentiwordnet
\ No newline at end of file
+from compling.analysis.sentiment.lexicon import Vader, Sentiwordnet, Sentix
\ No newline at end of file
