@@ -26,7 +26,7 @@ class SentimentAnalyzer(SentimentLexiconBased):
     """
 
     def __init__(self, tokens: Iterable[dict],
-                 group_by_field: str, id_index_field: str = None, date_field: str = None,
+                 group_by_field: Union[str, List[str]], id_index_field: str = None, date_field: str = None,
                  token_field: str = "text",
                  pos: Tuple[str, ...] = ('VERB', 'NOUN', 'ADJ', 'PROPN', 'ADV'), dep: Tuple[str, ...] = None, min_len=0, lang: str = None) -> None:
         """
